# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/litepie/team/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/litepie/team/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Litepie\\Team\\": "packages/litepie/team/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Litepie\Team\Providers\TeamServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Team'  => Litepie\Team\Facades\Team::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Litepie\\TeamTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Litepie\Team\Providers\TeamServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Litepie\Team\Providers\TeamServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Litepie\Team\Providers\TeamServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/team/{modulename}

**User**

    http://path-to-route-folder/user/team/{modulename}

**Public**

    http://path-to-route-folder/teams


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/team/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/team/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/team/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/team/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/team/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/team/{modulename}/{slug}
    METHOD: GET